package vdirsyncer

import (
	"encoding/json"
	"fmt"
	"os/exec"
)

type Config struct {
	Storages []Storage `json:"storages"`
}

type Storage struct {
	Type string `json:"type"`
	Name string `json:"instance_name"`
	Path string `json:"path"`
	// TODO: We might want to actualy pay attention to fileext too?
}

func GetVdirsyncerConfig() (*Config, error) {
	out, err := exec.Command("vdirsyncer", "showconfig").Output()
	if err != nil {
		return nil, fmt.Errorf("failed to get vdirsyncer config: %v", err)
	}

	config := &Config{}
	err = json.Unmarshal(out, config)

	if err != nil {
		return nil, fmt.Errorf("failed to parse vdirsyncer config: %v", err)
	}
	return config, err
}

func GetVdirsyncerStoragePaths() (paths []string, err error) {
	config, err := GetVdirsyncerConfig()
	if err != nil {
		return
	}

	storages := make([]string, 0)
	for _, storage := range config.Storages {
		if storage.Type == "filesystem" {
			storages = append(storages, storage.Path)
		}
	}

	return storages, nil
}
